@@ -1,5 +1,9 @@
 //! Error types
 
+// Related to the `Error` definition below.
+// TODO(soares): Update flex-error accordingly to address this.
+#![allow(clippy::use_self)]
+
 use flex_error::{define_error, DisplayOnly};
 use prost::DecodeError;
 use signature::Error as SignatureError;
